@@ -1,4 +1,5 @@
 import pandas as pd
+import matplotlib.pyplot as plt
 
 
 def view():
@@ -10,3 +11,10 @@ def view():
 def format_cols(df):
     formatted_headers = [x.lower().replace(' ', '_') for x in df.columns]
     return formatted_headers
+
+
+def label_graph(data, x, y, label):
+    for i in data.index:
+        record = data.loc[i]
+        ax = plt.gca()
+        ax.text(record[x] * 1.02, record[y], record[label], size='x-small')
